==> openflowplugin-extension-nicira-0.5.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/value/_case/FlowModAddMatchFromValue.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-add-match-from-value {
 *     leaf flow-mod-num-bits {
 *         type uint16;
 *     }
 *     leaf value {
 *         type uint16;
 *     }
 *     leaf src-field {
 *         type uint32;
 *     }
 *     leaf src-ofs {
 *         type uint16;
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-value-case/flow-mod-add-match-from-value</i>
 *
 * <p>To create instances of this class use {@link org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValueBuilder}.
 * @see org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValueBuilder
 *
 */
public interface FlowModAddMatchFromValue
    extends
    ChildOf<FlowModSpec>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mod-add-match-from-value").intern();

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    java.lang.Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Integer</code> <code>value</code>, or <code>null</code> if not present
     */
    java.lang.Integer getValue();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    java.lang.Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getSrcOfs();

}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/value/_case/FlowModAddMatchFromValue.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-add-match-from-value {
 *     leaf flow-mod-num-bits {
 *         type uint16;
 *     }
 *     leaf value {
 *         type uint16;
 *     }
 *     leaf src-field {
 *         type uint32;
 *     }
 *     leaf src-ofs {
 *         type uint16;
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-value-case/flow-mod-add-match-from-value</i>
 *
 * <p>To create instances of this class use {@link FlowModAddMatchFromValueBuilder}.
 * @see FlowModAddMatchFromValueBuilder
 *
 */
public interface FlowModAddMatchFromValue
    extends
    ChildOf<FlowModSpec>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mod-add-match-from-value").intern();

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    java.lang.Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Integer</code> <code>value</code>, or <code>null</code> if not present
     */
    java.lang.Integer getValue();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    java.lang.Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getSrcOfs();

}
